Child

Struct Child 

pub struct Child {
    pub stdin: Option<ChildStdin>,
    pub stdout: Option<ChildStdout>,
    pub stderr: Option<ChildStderr>,
    /* private fields */
}
A running child process, providing access to its standard I/O streams and the ability to wait for its completion.

Fields

stdin: Option<ChildStdin>stdout: Option<ChildStdout>stderr: Option<ChildStderr>

Implementations

Source

impl Child

pub async fn wait(self) -> Result<ExitStatus, Error>

Waits for the child process to exit, returning the exit status.

pub async fn wait_with_output(self) -> Result<Output, Error>

Waits for the child process to exit, returning the exit status, stdout, and stderr.