Russh Process Command
This crate provides an interface similar to std::process::Command for russh library.
It allows executing commands, streaming their output, and retrieving their exit status.
Features
- Mimics the
std::process::CommandAPI. - Provides asynchronous
stdin,stdout, andstderrstreams. - Supports retrieving the command’s
ExitStatus. - Provides
spawnandoutputmethods for more control over process handling.
Example
Modules
- client
- The extension for
russh::client
Structs
- Child
- A running child process, providing access to its standard I/O streams and the ability to wait for its completion.
- Child
Stderr - Represents the standard error (stderr) of a child process.
Implements
AsyncReadfor non-blocking I/O. - Child
Stdin - Represents the standard input (stdin) of a child process.
Implements
AsyncWritefor non-blocking I/O. - Child
Stdout - Represents the standard output (stdout) of a child process.
Implements
AsyncReadfor non-blocking I/O. - Command
- Represents a command to be executed over an SSH channel.
- Exit
Status - Output
- The result of a completed command, including exit status, standard output, and standard error.