pub struct Child {
pub stdin: Option<ChildStdin>,
pub stdout: Option<ChildStdout>,
pub stderr: Option<ChildStderr>,
/* private fields */
}Expand description
A running child process, providing access to its standard I/O streams and the ability to wait for its completion.
Fields
stdin: Option<ChildStdin>stdout: Option<ChildStdout>stderr: Option<ChildStderr>Implementations